var interfacecom_1_1sun_1_1star_1_1frame_1_1XFrame2 =
[
    [ "com::sun::star::task::XStatusIndicatorFactory", "interfacecom_1_1sun_1_1star_1_1frame_1_1XFrame2.html#a0700064fe1138da0e68a0cc0fbe7eeaa", null ],
    [ "XDispatchInformationProvider", "interfacecom_1_1sun_1_1star_1_1frame_1_1XFrame2.html#a08d2d67289e2ca5eb5c46b9c3514515d", null ],
    [ "XDispatchProvider", "interfacecom_1_1sun_1_1star_1_1frame_1_1XFrame2.html#a024de35e0d78cccdbba62395fe776882", null ],
    [ "XDispatchProviderInterception", "interfacecom_1_1sun_1_1star_1_1frame_1_1XFrame2.html#a09306c292b785533b2041afe9a6cf914", null ],
    [ "XFramesSupplier", "interfacecom_1_1sun_1_1star_1_1frame_1_1XFrame2.html#a17bb2f36b50d1cc5b9219121be134189", null ],
    [ "DispatchRecorderSupplier", "interfacecom_1_1sun_1_1star_1_1frame_1_1XFrame2.html#ae7ce87a93052ca52affe5161b0101f69", null ],
    [ "LayoutManager", "interfacecom_1_1sun_1_1star_1_1frame_1_1XFrame2.html#a7c29d4efff63a1386a1d6fa51ca59dfd", null ],
    [ "Title", "interfacecom_1_1sun_1_1star_1_1frame_1_1XFrame2.html#aa7b633091e7820b835d04d0d5fc197c7", null ],
    [ "UserDefinedAttributes", "interfacecom_1_1sun_1_1star_1_1frame_1_1XFrame2.html#a6fa54c86891f86d4750edc9ff3aacd93", null ]
];